==> haskell-monad-par-0.3.5-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.5
visibility:           public
id:                   monad-par-0.3.5-5lJqL7pDNJnHUgciguGZtC
key:                  monad-par-0.3.5-5lJqL7pDNJnHUgciguGZtC
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  cccb6b537d40fd5129e94612e6e879f3
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-par-0.3.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-par-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-par-0.3.5
hs-libraries:         HSmonad-par-0.3.5-5lJqL7pDNJnHUgciguGZtC
depends:
    abstract-deque-0.3-gvMRZHgovu35fmj4KXcl3
    abstract-par-0.3.3-81njJRkjRqmAeWCHawvyEp array-0.5.4.0
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0
    monad-par-extras-0.3.3-GBgueu4bi9MJ5KJC1zFl8U mtl-2.2.2
    mwc-random-0.15.0.1-DGSTWuGvf3vC5KGtZLUWiD
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.5-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.5
visibility:           public
id:                   monad-par-0.3.5-KKwFk515CK9UwyhRIHLby
key:                  monad-par-0.3.5-KKwFk515CK9UwyhRIHLby
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  ba8e6ebe0624fe19bb9174ae3181814c
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-8.10.2/site-local/monad-par-0.3.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/monad-par-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/monad-par-0.3.5
hs-libraries:         HSmonad-par-0.3.5-KKwFk515CK9UwyhRIHLby
depends:
    abstract-deque-0.3-575Y3ZrtnTi4vOCDDR4zwU
    abstract-par-0.3.3-81njJRkjRqmAeWCHawvyEp array-0.5.4.0
    base-4.14.1.0 containers-0.6.2.1 deepseq-1.4.4.0
    monad-par-extras-0.3.3-269eKTv0JeNDmZ1uIWBdmH mtl-2.2.2
    mwc-random-0.15.0.1-EbQXUaXAawH6jvmPVInGqz
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
